joined_rows_to_js_array

Function joined_rows_to_js_array 

pub fn joined_rows_to_js_array(rows: &[Rc<Row>], schemas: &[&Table]) -> JsValue
Converts a vector of Rows to a JavaScript array of objects using multiple schemas.

This function is used for JOIN queries where the result contains columns from multiple tables. The schemas parameter specifies the schemas of all joined tables in order. For duplicate column names across tables, we use table.column format to distinguish them.