projected_rows_to_js_array

Function projected_rows_to_js_array 

pub fn projected_rows_to_js_array(
    rows: &[Rc<Row>],
    column_names: &[String],
) -> JsValue
Converts a vector of projected Rows to a JavaScript array of objects.

This function is used when only specific columns are selected (projection). The column_names parameter specifies the names of the projected columns in the order they appear in the row.