explain_plan

Function explain_plan 

pub fn explain_plan(
    cache: &TableCache,
    table_name: &str,
    plan: LogicalPlan,
) -> ExplainResult
Explains a logical plan by showing the optimization stages.

Returns the logical plan, optimized plan, and physical plan as strings.